@@ -30,6 +30,7 @@
 #      10-Jan-2019  jdw pass down container name to processRecord() to allow for better diagnostics.
 #       5-Feb-2019  jdw generalize locatorList to locatorObjList and associated dependent changes,
 #                       and add __mergeContainers() -
+#      22-Sep-2019  jdw use sorted order of table objects within documents
 #
 #
 ##
@@ -62,7 +63,6 @@ class SchemaDefDataPrep(object):
 
     def __init__(self, schemaDefAccessObj, dtObj=None, workPath=None, verbose=True):
         self.__verbose = verbose
-        self.__workPath = workPath
         self.__debug = False
         self.__sD = schemaDefAccessObj
         self.__mU = MarshalUtil(workPath=workPath)
@@ -83,7 +83,7 @@ class SchemaDefDataPrep(object):
             self.__schemaIdExcludeD = {sId: True for sId in schemaIdList}
             return True
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
         return False
 
     def setSchemaIdIncludeList(self, schemaIdList):
@@ -96,7 +96,7 @@ class SchemaDefDataPrep(object):
             self.__schemaIdIncludeD = {sId: True for sId in schemaIdList}
             return True
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
         return False
 
     def __getTimeStamp(self):
@@ -104,7 +104,7 @@ class SchemaDefDataPrep(object):
         ts = utcnow.strftime("%Y-%m-%d:%H:%M:%S")
         return ts
 
-    def __mergeContainers(self, locatorObj, format="mmcif", mergeTarget=0):
+    def __mergeContainers(self, locatorObj, fmt="mmcif", mergeTarget=0):
         """ Consolidate content in auxiliary files locatorObj[1:] into
             locatorObj[0] container index 'mergeTarget'.
 
@@ -113,16 +113,16 @@ class SchemaDefDataPrep(object):
         cL = []
         try:
             if isinstance(locatorObj, str):
-                cL = self.__mU.doImport(locatorObj, format=format)
+                cL = self.__mU.doImport(locatorObj, fmt=fmt)
                 return cL if cL else []
-            elif isinstance(locatorObj, (list, tuple)) and len(locatorObj) > 0:
-                d = locatorObj[0]
-                kw = d['kwargs']
-                cL = self.__mU.doImport(d['locator'], format=d['format'], **kw)
-                if cL and len(cL) > 0:
-                    for d in locatorObj[1:]:
-                        kw = d['kwargs']
-                        rObj = self.__mU.doImport(d['locator'], format=d['format'], **kw)
+            elif isinstance(locatorObj, (list, tuple)) and locatorObj:
+                dD = locatorObj[0]
+                kw = dD["kwargs"]
+                cL = self.__mU.doImport(dD["locator"], fmt=dD["fmt"], **kw)
+                if cL:
+                    for dD in locatorObj[1:]:
+                        kw = dD["kwargs"]
+                        rObj = self.__mU.doImport(dD["locator"], fmt=dD["fmt"], **kw)
                         mergeL = rObj if rObj else []
                         for mc in mergeL:
                             cL[mergeTarget].merge(mc)
@@ -131,7 +131,7 @@ class SchemaDefDataPrep(object):
             else:
                 return []
         except Exception as e:
-            logger.exception("Failing for %r with %s" % (locatorObj, str(e)))
+            logger.exception("Failing for %r with %s", locatorObj, str(e))
 
         return cL
 
@@ -139,12 +139,13 @@ class SchemaDefDataPrep(object):
         """ Return the data container list obtained by parsing the input locator list.
         """
         cL = []
+        _ = filterType
         for locatorObj in locatorObjList:
-            # myContainerList = self.__mU.doImport(locatorObj, format="mmcif")
+            # myContainerList = self.__mU.doImport(locatorObj, fmt="mmcif")
             # logger.info("locatorObj is %r" % type(locatorObj))
-            myContainerList = self.__mergeContainers(locatorObj, format="mmcif", mergeTarget=0)
-            for c in myContainerList:
-                cL.append(c)
+            myContainerList = self.__mergeContainers(locatorObj, fmt="mmcif", mergeTarget=0)
+            for cA in myContainerList:
+                cL.append(cA)
         return cL
 
     def getLocatorsFromPaths(self, locatorObjList, pathList, locatorIndex=0):
@@ -159,15 +160,15 @@ class SchemaDefDataPrep(object):
             #
             locIdx = {}
             for ii, locatorObj in enumerate(locatorObjList):
-                if 'locator' in locatorObj[locatorIndex]:
-                    locIdx[locatorObj[locatorIndex]['locator']] = ii
+                if "locator" in locatorObj[locatorIndex]:
+                    locIdx[locatorObj[locatorIndex]["locator"]] = ii
             #
             for pth in pathList:
                 jj = locIdx[pth] if pth in locIdx else None
                 if jj is not None:
                     rL.append(locatorObjList[jj])
         except Exception as e:
-            logger.exception("Faliing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
         #
         return rL
 
@@ -176,12 +177,12 @@ class SchemaDefDataPrep(object):
             if locatorObjList and isinstance(locatorObjList[0], str):
                 return locatorObjList
             else:
-                return [locatorObj[locatorIndex]['locator'] for locatorObj in locatorObjList]
+                return [locatorObj[locatorIndex]["locator"] for locatorObj in locatorObjList]
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
         return []
 
-    def fetch(self, locatorObjList, styleType="rowwise_by_id", filterType="none", dataSelectors=None):
+    def fetch(self, locatorObjList, styleType="rowwise_by_id", filterType="none", dataSelectors=None, useNameFlag=True, collectionName=None):
         """ Return a dictionary of loadable data for each table defined in the current schema
             definition object.   Data are extracted from all files in the input file list,
             and this is added in single schema instance such that data from multiple files are appended to a
@@ -200,11 +201,11 @@ class SchemaDefDataPrep(object):
                 filterTypes: "drop-empty-attributes|drop-empty-tables|skip-max-width|assign-dates"
 
         """
-        schemaDataDictById, containerNameList, _ = self.__fetch(locatorObjList, filterType, dataSelectors=dataSelectors)
-        schemaDataDict = self.__reShape.applyShape(schemaDataDictById, styleType=styleType)
+        schemaDataDictById, containerNameList, _ = self.__fetch(locatorObjList, filterType, dataSelectors=dataSelectors, useNameFlag=useNameFlag)
+        schemaDataDict = self.__reShape.applyShape(schemaDataDictById, styleType=styleType, collectionName=collectionName)
         return schemaDataDict, containerNameList
 
-    def fetchDocuments(self, locatorObjList, styleType="rowwise_by_id", filterType="none", logSize=False, dataSelectors=None, sliceFilter=None):
+    def fetchDocuments(self, locatorObjList, styleType="rowwise_by_id", filterType="none", dataSelectors=None, sliceFilter=None, useNameFlag=True, collectionName=None):
         """ Return a list of dictionaries of loadable data for each table defined in the current schema
             definition object.   Data are extracted from the each input file, and each data
             set is stored in a separate schema instance (document).  The organization
@@ -220,24 +221,25 @@ class SchemaDefDataPrep(object):
                      columnwise_by_name: dict[<tableName>] = {'atName': [val1, val2,... ], atName2: [val1,val2, ... ], ...}
 
                  filterTypes: "drop-empty-attributes|drop-empty-tables|skip-max-width|assign-dates"
-
                  sliceFilter: name of slice filter
+                 useNameFlag: use container name rather than container UID as a unique identifier
+                 collectionName:  name target collection for the processed documents
         """
         schemaDataDictList = []
         containerNameList = []
         rejectLocatorObjList = []
         for locator in locatorObjList:
-            schemaDataDictById, cnList, rL = self.__fetch([locator], filterType, dataSelectors=dataSelectors)
+            schemaDataDictById, cnList, rL = self.__fetch([locator], filterType, dataSelectors=dataSelectors, useNameFlag=useNameFlag)
             rejectLocatorObjList.extend(rL)
             if not schemaDataDictById:
                 continue
-            sddL = self.__reShape.applySlicedShape(schemaDataDictById, styleType=styleType, sliceFilter=sliceFilter)
+            sddL = self.__reShape.applySlicedShape(schemaDataDictById, styleType=styleType, sliceFilter=sliceFilter, collectionName=collectionName)
             schemaDataDictList.extend(sddL)
             containerNameList.extend(cnList)
         #
         return schemaDataDictList, containerNameList, rejectLocatorObjList
 
-    def process(self, containerList, styleType="rowwise_by_id", filterType="none", dataSelectors=None):
+    def process(self, containerList, styleType="rowwise_by_id", filterType="none", dataSelectors=None, useNameFlag=True, collectionName=None):
         """ Return a dictionary of loadable data for each table defined in the current schema
             definition object.   Data are extracted from all files in the input container list,
             and this is added in single schema instance such that data from multiple files are appended to a
@@ -256,12 +258,12 @@ class SchemaDefDataPrep(object):
 
 
         """
-        schemaDataDictById, containerNameList, _ = self.__process(containerList, filterType, dataSelectors=dataSelectors)
-        schemaDataDict = self.__reShape.applyShape(schemaDataDictById, styleType=styleType)
+        schemaDataDictById, containerNameList, _ = self.__process(containerList, filterType, dataSelectors=dataSelectors, useNameFlag=useNameFlag)
+        schemaDataDict = self.__reShape.applyShape(schemaDataDictById, styleType=styleType, collectionName=collectionName)
 
         return schemaDataDict, containerNameList
 
-    def processDocuments(self, containerList, styleType="rowwise_by_id", filterType="none", logSize=False, dataSelectors=None, sliceFilter=None):
+    def processDocuments(self, containerList, styleType="rowwise_by_id", filterType="none", dataSelectors=None, sliceFilter=None, useNameFlag=True, collectionName=None):
         """ Return a list of dictionaries of loadable data for each table defined in the current schema
             definition object.   Data are extracted from the each input container, and each data
             set is stored in a separate schema instance (document).  The organization of the loadable
@@ -277,58 +279,191 @@ class SchemaDefDataPrep(object):
                      columnwise_by_name: dict[<tableName>] = {'atName': [val1, val2,... ], atName2: [val1,val2, ... ], ...}
 
             filterTypes:  "drop-empty-attributes|drop-empty-tables|skip-max-width|assign-dates"
-
             sliceFilter: name of slice filter
+            useNameFlag: use container name rather than container UID as a unique identifier
+            collectionName:  name target collection for the processed documents
         """
         schemaDataDictList = []
-        containerNameList = []
-        rejectPathList = []
+        containerIdList = []
+        rejectIdList = []
         for container in containerList:
-            schemaDataDictById, _, rL = self.__process([container], filterType, dataSelectors=dataSelectors)
-            rejectPathList.extend(rL)
+            schemaDataDictById, _, rL = self.__process([container], filterType, dataSelectors=dataSelectors, useNameFlag=useNameFlag)
+            rejectIdList.extend(rL)
             if not schemaDataDictById:
                 continue
             #
-            logger.debug("Reshape container %s using %s" % (container.getName(), sliceFilter))
-            sddL = self.__reShape.applySlicedShape(schemaDataDictById, styleType=styleType, sliceFilter=sliceFilter)
-            if len(sddL) == 0:
-                logger.info("No result on reshaping container %s using %s" % (container.getName(), sliceFilter))
+            logger.debug("Reshape container %s for collection %s using slice filter %s", container.getName(), collectionName, sliceFilter)
+            sddL = self.__reShape.applySlicedShape(schemaDataDictById, styleType=styleType, sliceFilter=sliceFilter, collectionName=collectionName)
+            if not sddL:
+                logger.debug("No result on reshaping container %s collection %s slice filter %s", container.getName(), collectionName, sliceFilter)
             else:
                 schemaDataDictList.extend(sddL)
                 #
                 # Match the container name to the generated reshaped objects
-                cName = container.getName()
-                cnList = [cName for i in range(len(sddL))]
-                containerNameList.extend(cnList)
+                try:
+                    if useNameFlag:
+                        cId = container.getName()
+                    else:
+                        cId = container.getProp("uid")
+                except Exception:
+                    cId = container.getName()
+                cIdList = [cId for i in range(len(sddL))]
+                containerIdList.extend(cIdList)
 
-        rejectPathList = list(set(rejectPathList))
+        rejectIdList = list(set(rejectIdList))
+        logger.debug("containerIdList %r schemaDataDictList %r", containerIdList, schemaDataDictList)
         #
-        return schemaDataDictList, containerNameList, rejectPathList
+        return schemaDataDictList, containerIdList, rejectIdList
 
-    def addDocumentPrivateAttributes(self, docList, collectionName):
+    def addDocumentPrivateAttributes(self, docList, collectionName, styleType="rowwise_by_name"):
         """ For the input collection, add private document attributes to the input document list.
         """
+        if styleType not in ["rowwise_by_name", "rowwise_by_name_with_cardinality"]:
+            logger.error("Unsupported document style %s", styleType)
+            return docList
         try:
-            d = {}
+            doc = {}
             privDocKeyL = self.__sD.getPrivateDocumentAttributes(collectionName)
+            version = self.__sD.getCollectionVersion(collectionName)
+            #
             if privDocKeyL:
-                for pdk in privDocKeyL:
-                    catName = pdk['CATEGORY_NAME']
-                    atName = pdk['ATTRIBUTE_NAME']
-                    pName = pdk['PRIVATE_DOCUMENT_NAME']
-                    isMandatory = pdk['MANDATORY']
-                    for d in docList:
-                        if catName in d and atName in d[catName] and d[catName][atName] and d[catName][atName] not in ['.', '?']:
-                            d[pName] = d[catName][atName]
+                for doc in docList:
+                    for pdk in privDocKeyL:
+                        pName = pdk["PRIVATE_DOCUMENT_NAME"]
+                        isMandatory = pdk["MANDATORY"]
+                        if pdk["UPDATE_ON_LOAD"]:
+                            if pdk["NAME"] == "rcsb_schema_container_identifiers.collection_schema_version":
+                                doc[pName] = version
+
                         else:
-                            if isMandatory:
-                                logger.info("Skipping private key for %s %s %r %r" % (catName, atName, pdk, list(d.items())[:5]))
+                            catName = pdk["CATEGORY_NAME"]
+                            atName = pdk["ATTRIBUTE_NAME"]
+                            #
+                            if catName in doc and atName in doc[catName] and doc[catName][atName] and doc[catName][atName] not in [".", "?"]:
+                                doc[pName] = doc[catName][atName]
+                            else:
+                                if isMandatory:
+                                    logger.info("Skipping private key for %s %s %s %r %r", collectionName, catName, atName, pdk, list(doc.items())[:5])
         except Exception as e:
-            logger.exception("Failing with %s : %r" % (str(e), list(d.items())[:5]))
+            logger.exception("Failing with %s : %r", str(e), list(doc.items())[:5])
         #
         return docList
 
-    def __fetch(self, locatorObjList, filterType, dataSelectors=None):
+    def addDocumentSubCategoryAggregates(self, docList, collectionName, styleType="rowwise_by_name", removeSubCategoryPrefix=True):
+        """ For the input collection, add subcategory aggregates to the input document list.
+        """
+        if styleType not in ["rowwise_by_name", "rowwise_by_name_with_cardinality"]:
+            logger.error("Unsupported document style %s", styleType)
+            return docList
+        try:
+            dD = {}
+            scAgL = self.__sD.getSubCategoryAggregates(collectionName)
+            if scAgL:
+                scAgD = {}
+                logger.debug("%s processing subcategory aggregates %r", collectionName, scAgL)
+                for scAg in scAgL:
+                    scD = {}
+                    sIdL = self.__sD.getSubCategorySchemaIdList(scAg)
+                    for sId in sIdL:
+                        atIdL = self.__sD.getSubCategoryAttributeIdList(sId, scAg)
+                        scD[self.__sD.getSchemaName(sId)] = [self.__sD.getAttributeName(sId, atId) for atId in atIdL]
+                    scAgD[scAg] = scD
+                logger.debug("%s subcategory aggregate name dictionary %r", collectionName, scAgD)
+                #
+                for doc in docList:
+                    for scAg, scD in scAgD.items():
+                        for sName in scD:
+                            # logger.info("sName %s scAg %r scD %r", sName, scAg, scD)
+                            if sName not in doc:
+                                continue
+                            #
+                            hasUnitCard = self.__sD.getSubCategoryAggregatesUnitCardinality(collectionName, scAg)
+                            atNameAllL = scD[sName]
+                            logger.debug("\n -- %s %s agg %s unit cardinality %r obj %s type %r", sName, collectionName, hasUnitCard, scAg, sName, type(doc[sName]))
+                            # logger.info("\n -- %s %s type %r", sName, collectionName, type(doc[sName]))
+                            # logger.info("\n -- %s %s atNameAllL %r", sName, collectionName, atNameAllL)
+                            if isinstance(doc[sName], list):
+                                for rowD in doc[sName]:
+                                    atNameL = list(set(atNameAllL).intersection(set(rowD.keys())))
+                                    # logger.info(" - QQQ - sName %s atNameAllL %r rowD.keys()(set) %r atNameL %r", sName, set(atNameAllL), set(rowD.keys()), atNameL)
+                                    if atNameL and set(atNameL).issubset(set(rowD.keys())):
+                                        # logger.info(" - TTT - sName %s (%r) %r", sName, hasUnitCard, [type(rowD[atName]) for atName in atNameL])
+                                        if hasUnitCard:
+                                            # all members of the the subcategory must be simple types -
+                                            dD = {}
+                                            for atName in atNameL:
+                                                cAtName = atName.replace(scAg + "_", "") if removeSubCategoryPrefix else atName
+                                                # dD[cAtName] = rowD[atName]
+                                                # JDW filter missing values -
+                                                if not rowD[atName] or rowD[atName] in [".", "?"]:
+                                                    continue
+                                                dD[cAtName] = rowD[atName]
+                                            rowD[scAg] = dD
+                                        else:
+                                            # all members of the the subcategory must be list type -
+                                            atLenL = [len(rowD[atName]) for atName in atNameL]
+                                            atLen = min(atLenL)
+                                            # logger.info("%s %s %r Candidate list row is %r", scAg, sName, atNameL, rowD)
+                                            # copy all of the data to the new aggregate object
+                                            rL = []
+                                            for ii in range(atLen):
+                                                dD = {}
+                                                for atName in atNameL:
+                                                    cAtName = atName.replace(scAg + "_", "") if removeSubCategoryPrefix else atName
+                                                    # JDW filter missing values
+                                                    if not rowD[atName][ii] or rowD[atName][ii] in [".", "?"]:
+                                                        continue
+                                                    dD[cAtName] = rowD[atName][ii]
+                                                rL.append(dD)
+                                            rowD[scAg] = rL
+                                        #
+                                        for atName in atNameL:
+                                            del rowD[atName]
+                                        logger.debug("Processed list row is %r", rowD)
+                            elif isinstance(doc[sName], dict):
+                                atNameL = list(set(atNameAllL).intersection(set(doc[sName].keys())))
+                                if atNameL and set(atNameL).issubset(set(doc[sName].keys())):
+                                    # logger.info("Candidate dict row is %r", doc[sName])
+                                    if hasUnitCard:
+                                        # all members of the the subcategory must be simple types -
+                                        dD = {}
+                                        dD = {}
+                                        for atName in atNameL:
+                                            cAtName = atName.replace(scAg + "_", "") if removeSubCategoryPrefix else atName
+                                            # JDW filter missing values
+                                            if not doc[sName][atName][ii] or doc[sName][atName][ii] in [".", "?"]:
+                                                continue
+                                            dD[cAtName] = doc[sName][atName][ii]
+                                        doc[sName][scAg] = dD
+                                    else:
+                                        # all members of the the subcategory must be list type -
+                                        atLenL = [len(doc[sName][atName]) for atName in atNameL]
+                                        atLen = min(atLenL)
+                                        # copy all of the data to the new aggregate object
+                                        rL = []
+                                        for ii in range(atLen):
+                                            dD = {}
+                                            for atName in atNameL:
+                                                cAtName = atName.replace(scAg + "_", "") if removeSubCategoryPrefix else atName
+                                                # JDW filter missing values
+                                                if not doc[sName][atName][ii] or doc[sName][atName][ii] in [".", "?"]:
+                                                    continue
+                                                dD[cAtName] = doc[sName][atName][ii]
+                                            rL.append(dD)
+                                        doc[sName][scAg] = rL
+                                    #
+                                    for atName in atNameL:
+                                        del doc[sName][atName]
+                                    logger.debug("Processed dict row is %r", doc[sName])
+                            else:
+                                logger.error("%s unanticipated document data type for sName %s", collectionName, sName)
+
+        except Exception as e:
+            logger.exception("Failing with %s : %r", str(e), list(dD.items())[:5])
+        #
+        return docList
+
+    def __fetch(self, locatorObjList, filterType, dataSelectors=None, useNameFlag=True):
         """ Internal method to create loadable data corresponding to the table schema definition
             from the input list of data files.
 
@@ -340,25 +475,28 @@ class SchemaDefDataPrep(object):
         startTime = time.time()
         #
         rejectLocatorObjList = []
-        containerNameList = []
+        containerIdList = []
         schemaDataDict = {}
         for locatorObj in locatorObjList:
-            # myContainerList = self.__mU.doImport(locatorObj, format="mmcif")
-            myContainerList = self.__mergeContainers(locatorObj, format="mmcif", mergeTarget=0)
+            # myContainerList = self.__mU.doImport(locatorObj, fmt="mmcif")
+            myContainerList = self.__mergeContainers(locatorObj, fmt="mmcif", mergeTarget=0)
             cL = []
-            for c in myContainerList:
-                if self.__testdataSelectors(c, dataSelectors):
-                    cL.append(c)
-                    # self.__loadInfo[c.getName()] = {'load_date': self.__getTimeStamp(), 'locator': locatorObj}
+            for cA in myContainerList:
+                if self.__testdataSelectors(cA, dataSelectors):
+                    cL.append(cA)
+
+                    if useNameFlag:
+                        containerIdList.append(cA.getName())
+                    else:
+                        containerIdList.append(cA.getProp("uid"))
                 else:
                     rejectLocatorObjList.append(locatorObj)
             self.__mapData(cL, schemaDataDict, filterType)
-            containerNameList.extend([myC.getName() for myC in myContainerList])
         #
         schemaDataDictF = {}
-        if 'drop-empty-tables' in filterType:
+        if "drop-empty-tables" in filterType:
             for k, v in schemaDataDict.items():
-                if len(v) > 0:
+                if v:
                     schemaDataDictF[k] = v
         else:
             schemaDataDictF = schemaDataDict
@@ -368,55 +506,54 @@ class SchemaDefDataPrep(object):
         #
         #
         endTime = time.time()
-        logger.debug("completed at %s (%.3f seconds)" %
-                     (time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - startTime))
+        logger.debug("completed at %s (%.3f seconds)", time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - startTime)
 
-        return schemaDataDictF, containerNameList, rejectLocatorObjList
+        return schemaDataDictF, containerIdList, rejectLocatorObjList
 
-    def __process(self, containerList, filterType, dataSelectors=None):
+    def __process(self, containerList, filterType, dataSelectors=None, useNameFlag=True):
         """ Internal method to create loadable data corresponding to the table schema definition
             from the input container list.
 
-            Returns: dicitonary d[<tableId>] = [ row1Dict[attributeId]=value,  row2dict[], .. ]
+            Returns: dictionary d[<tableId>] = [ row1Dict[attributeId]=value,  row2dict[], .. ]
                                 and
-                     processed container name list. []
-                     list of paths or names of rejected containers. []
+                     suceessfully processed container id list. []
+                     list of rejected containers ids. []
 
         """
         startTime = time.time()
         #
-        rejectPathList = []
-        containerNameList = []
+        rejectIdList = []
+        containerIdList = []
         schemaDataDict = {}
         cL = []
-        for c in containerList:
-            if self.__testdataSelectors(c, dataSelectors):
-                cL.append(c)
+        for cA in containerList:
+            if self.__testdataSelectors(cA, dataSelectors):
+                logger.debug("useNameFlag %r name %r uid %r", useNameFlag, cA.getName(), cA.getProp("uid"))
+                cL.append(cA)
+                if useNameFlag:
+                    containerIdList.append(cA.getName())
+                else:
+                    containerIdList.append(cA.getProp("uid"))
             else:
-                try:
-                    # rejectList.append(self.__loadInfo[c.getName()]['locator'])
-                    rejectPathList.append(c.getProp['locator'])
-                except Exception:
-                    rejectPathList.append(c.getName())
+                if useNameFlag:
+                    rejectIdList.append(cA.getName())
+                else:
+                    rejectIdList.append(cA.getProp("uid"))
         #
         self.__mapData(cL, schemaDataDict, filterType)
-        containerNameList.extend([myC.getName() for myC in containerList])
-        #
-        #
         schemaDataDictF = {}
-        if 'drop-empty-tables' in filterType:
+        if "drop-empty-tables" in filterType:
             for k, v in schemaDataDict.items():
-                if len(v) > 0:
+                if v:
                     schemaDataDictF[k] = v
         else:
             schemaDataDictF = schemaDataDict
         #
         #
         endTime = time.time()
-        logger.debug("completed at %s (%.3f seconds)\n" %
-                     (time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - startTime))
+        logger.debug("completed at %s (%.3f seconds)", time.strftime("%Y %m %d %H:%M:%S", time.localtime()), endTime - startTime)
 
-        return schemaDataDictF, containerNameList, rejectPathList
+        return schemaDataDictF, containerIdList, rejectIdList
 
     def __testdataSelectors(self, container, dataSelectors):
         """ Test the if the input container satisfies the input content/data selectors.
@@ -425,74 +562,75 @@ class SchemaDefDataPrep(object):
 
             Return:  True fo sucess or False otherwise
         """
-        logger.debug("Applying selectors: %r" % dataSelectors)
         if not dataSelectors:
             return True
         try:
+            logger.debug("On container %s applying selectors: %r", container.getName(), dataSelectors)
             for cs in dataSelectors:
                 csDL = self.__sD.getDataSelectors(cs)
                 for csD in csDL:
-                    tn = csD['CATEGORY_NAME']
-                    an = csD['ATTRIBUTE_NAME']
-                    vals = csD['VALUES']
-                    logger.debug("Applying selector %s: tn %s an %s vals %r" % (cs, tn, an, vals))
+                    tn = csD["CATEGORY_NAME"]
+                    an = csD["ATTRIBUTE_NAME"]
+                    vals = csD["VALUES"]
+                    logger.debug("Applying selector %s: tn %s an %s vals %r", cs, tn, an, vals)
                     if not container.exists(tn):
                         return False
                     catObj = container.getObj(tn)
                     numRows = catObj.getRowCount()
                     if numRows:
                         for ii in range(numRows):
-                            logger.debug("Testing %s type %r row %d of %d" % (an, type(an), ii, numRows))
+                            logger.debug("Testing %s type %r row %d of %d", an, type(an), ii, numRows)
                             v = catObj.getValue(attributeName=an, rowIndex=ii)
                             if v not in vals:
-                                logger.debug("Selector %s rejects : tn %s an %s value %r" % (cs, tn, an, v))
+                                logger.debug("Selector %s rejects : tn %s an %s value %r", cs, tn, an, v)
                                 return False
                     else:
-                        logger.debug("Selector %s rejects container with missing category %s" % (cs, tn))
+                        logger.debug("Selector %s rejects container with missing category %s", cs, tn)
                         return False
             #
             # all selectors satisfied
             return True
         except Exception as e:
-            logger.exception("Failing with %s" % str(e))
+            logger.exception("Failing with %s", str(e))
 
         return False
 
     def __showOverwrite(self):
         #
-        if (self.__verbose):
-            if len(self.__overWrite) > 0:
+        if self.__verbose:
+            if self.__overWrite:
                 for k, v in self.__overWrite.items():
-                    logger.debug("+SchemaDefLoader(load) %r maximum width %r" % (k, v))
+                    logger.debug("+SchemaDefLoader(load) %r maximum width %r", k, v)
 
     def __evalMapFunction(self, dataContainer, rowDList, attributeId, functionName, functionArgs=None):
         """ Evaluate dynamic schema methods on the input data container.
 
         """
         # logger.debug("Evaluating function %s on attribute %s" % (functionName, attributeId))
+        _ = functionArgs
         fn = functionName.lower()
         cName = dataContainer.getName()
-        if (fn in "datablockid()"):
+        if fn in "datablockid()":
             val = cName
             for rowD in rowDList:
                 rowD[attributeId] = val
-        elif (fn == "getdatetime()"):
+        elif fn == "getdatetime()":
             # val = self.__loadInfo[cName]['load_date'] if cName in self.__loadInfo else self.__getTimeStamp()
-            v = dataContainer.getProp('load_date')
+            v = dataContainer.getProp("load_date")
             val = v if v else self.__getTimeStamp()
             for rowD in rowDList:
                 rowD[attributeId] = val
-        elif (fn == "getlocator()"):
+        elif fn == "getlocator()":
             # val = self.__loadInfo[cName]['locator'] if cName in self.__loadInfo else 'unknown'
-            v = dataContainer.getProp('locator')
-            val = v if v else 'unknown'
+            v = dataContainer.getProp("locator")
+            val = v if v else "unknown"
             for rowD in rowDList:
                 rowD[attributeId] = val
-        elif (fn == "rowindex()"):
+        elif fn == "rowindex()":
             for ii, rowD in enumerate(rowDList, 1):
                 rowD[attributeId] = ii
         else:
-            logger.error("Unsupported dynamic method %s for attribute %s" % (functionName, attributeId))
+            logger.error("Unsupported dynamic method %s for attribute %s", functionName, attributeId)
             return False
 
         return True
@@ -515,7 +653,7 @@ class SchemaDefDataPrep(object):
             selectedTableIdList = self.__sD.getSchemaIdList()
         #
         for myContainer in containerList:
-            for tableId in selectedTableIdList:
+            for tableId in sorted(selectedTableIdList):
                 if not self.__sD.hasSchemaObject(tableId):
                     # logger.debug("Skipping undefined table %s" % tableId)
                     continue
@@ -563,6 +701,7 @@ class SchemaDefDataPrep(object):
             mapped from the input instance category.
         """
         #
+        _ = filterType
         retList = []
         catObj = myContainer.getObj(categoryName)
         if catObj is None:
@@ -570,8 +709,8 @@ class SchemaDefDataPrep(object):
         attributeNameList = catObj.getAttributeList()
         #
         for row in catObj.getRowList():
-            d = self.__dtObj.processRecord(tObj.getId(), row, attributeNameList, containerName=myContainer.getName())
-            retList.append(d)
+            dD = self.__dtObj.processRecord(tObj.getId(), row, attributeNameList, containerName=myContainer.getName())
+            retList.append(dD)
 
         return retList
 
@@ -586,6 +725,7 @@ class SchemaDefDataPrep(object):
             mapped from the input instance category.
         """
         # Consider mD as orderdict
+        _ = filterType
         mD = {}
         for categoryName in categoryNameList:
             catObj = myContainer.getObj(categoryName)
@@ -606,11 +746,11 @@ class SchemaDefDataPrep(object):
                         mK.append(row[attributeIndexDict[atName]])
                     except Exception as e:
                         # would reflect a serious issue of missing key-
-                        if (self.__debug):
-                            logger.exception("Failing with %s" % str(e))
+                        if self.__debug:
+                            logger.exception("Failing with %s", str(e))
                 #
 
-                d = self.__dtObj.processRecord(tObj.getId(), row, attributeNameList, containerName=myContainer.getName())
+                dD = self.__dtObj.processRecord(tObj.getId(), row, attributeNameList, containerName=myContainer.getName())
 
                 #
                 # Update this row using exact matching of the merging key --
@@ -620,10 +760,10 @@ class SchemaDefDataPrep(object):
                 if tk not in mD:
                     mD[tk] = {}
 
-                mD[tk].update(d)
+                mD[tk].update(dD)
 
         return mD.values()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
